@@ -121,7 +121,7 @@ moon_reader = function(
       stop("mathjax = 'local' does not work for moon_reader()")
     if (!is.null(mathjax)) {
       if (identical(mathjax, 'default')) {
-        mathjax = 'https://cdn.bootcss.com/mathjax/2.7.1/MathJax.js?config=TeX-MML-AM_CHTML'
+        mathjax = 'https://mathjax.rstudio.com/latest/MathJax.js?config=TeX-MML-AM_CHTML'
       }
       pandoc_args = c(pandoc_args, '-V', paste0('mathjax-url=', mathjax))
       mathjax = NULL
@@ -133,24 +133,32 @@ moon_reader = function(
   }
 
   optk = list()
-  hook_highlight = if (isTRUE(nature$highlightLines)) {
-    # an ugly way to access the `source` hook of markdown output in knitr
-    hook_source = local({
+
+  highlight_hooks = NULL
+  if (isTRUE(nature$highlightLines)) {
+    # an ugly way to access hooks of markdown output in knitr
+    hooks = local({
       ohooks = knitr::knit_hooks$get(); on.exit(knitr::knit_hooks$restore(ohooks))
       knitr::render_markdown()
-      knitr::knit_hooks$get('source')
+      knitr::knit_hooks$get(c('source', 'output'))
     })
-
-    function(x, options) {
-      res = hook_source(x, options)
-      highlight_code(res)
-    }
+    highlight_hooks = list(
+      source = function(x, options) {
+        hook = hooks[['source']]
+        res = hook(x, options)
+        highlight_code(res)
+      },
+      output = function(x, options) {
+        hook = hooks[['output']]
+        res = highlight_output(x, options)
+        hook(res, options)
+      }
+    )
   }
 
+
   rmarkdown::output_format(
-    if (!is.null(hook_highlight)) {
-      rmarkdown::knitr_options(knit_hooks = list(source = hook_highlight))
-    },
+    rmarkdown::knitr_options(knit_hooks = highlight_hooks),
     NULL, clean_supporting = self_contained,
     pre_knit = function(...) {
       optk <<- knitr::opts_knit$get()
